@@ -110,7 +110,6 @@ ets <- function(
   use.initial.values = FALSE,
   ...
 ) {
-  # dataname <- substitute(y)
   opt.crit <- match.arg(opt.crit)
   bounds <- match.arg(bounds)
   ic <- match.arg(ic)
@@ -128,7 +127,7 @@ ets <- function(
   }
 
   orig.y <- y
-  if (identical(class(model), "ets") && is.null(lambda)) {
+  if (inherits(model, "ets") && is.null(lambda)) {
     lambda <- model$lambda
   }
   if (!is.null(lambda)) {
@@ -269,7 +268,7 @@ ets <- function(
     seasontype <- "N"
   }
   if (m == 1) {
-    if (seasontype == "A" || seasontype == "M") {
+    if (seasontype %in% c("A", "M")) {
       stop("Nonseasonal data")
     } else {
       substr(model, 3, 3) <- seasontype <- "N"
@@ -299,7 +298,7 @@ ets <- function(
     }
   }
 
-  data.positive <- (min(y, na.rm=TRUE) > 0)
+  data.positive <- (min(y, na.rm = TRUE) > 0)
 
   if (!data.positive && errortype == "M") {
     stop("Inappropriate model for data with negative or zero values")
@@ -312,10 +311,10 @@ ets <- function(
   n <- sum(!is.na(y))
   # Check we have enough data to fit a model
   npars <- 2L # alpha + l0
-  if (trendtype == "A" || trendtype == "M") {
+  if (trendtype %in% c("A", "M")) {
     npars <- npars + 2L
   } # beta + b0
-  if (seasontype == "A" || seasontype == "M") {
+  if (seasontype %in% c("A", "M")) {
     npars <- npars + m
   } # gamma + s
   if (!is.null(damped)) {
@@ -327,7 +326,7 @@ ets <- function(
     if (!is.null(damped) && damped) {
       warning("Not enough data to use damping")
     }
-    if (seasontype == "A" || seasontype == "M") {
+    if (seasontype %in% c("A", "M")) {
       fit <- try(
         HoltWintersZZ(
           orig.y,
@@ -352,7 +351,7 @@ ets <- function(
         warning("Seasonal component could not be estimated")
       }
     }
-    if (trendtype == "A" || trendtype == "M") {
+    if (trendtype %in% c("A", "M")) {
       fit <- try(
         HoltWintersZZ(
           orig.y,
@@ -554,8 +553,6 @@ ets <- function(
   }
 
   model$lambda <- lambda
-  # model$call$data <- dataname
-
   structure(model, class = c("fc_model", "ets"))
 }
 
@@ -722,7 +719,7 @@ etsmodel <- function(
     ))
   }
 
-  env <- etsTargetFunctionInit(
+  env <- etsTargetFunctionInitWrapper(
     par = par,
     y = y,
     nstate = nstate,
@@ -741,8 +738,7 @@ etsmodel <- function(
     pnames2 = names(par.noopt)
   )
 
-  fred <- .Call(
-    "etsNelderMead",
+  fred <- etsNelderMead(
     par,
     env,
     -Inf,
@@ -751,14 +747,13 @@ etsmodel <- function(
     0.5,
     2.0,
     trace,
-    maxit,
-    PACKAGE = "forecast"
+    maxit
   )
   fit.par <- fred$par
   names(fit.par) <- names(par)
   init.state <- fit.par[(np - nstate + 1):np]
 
-    # Add extra state
+  # Add extra state
   if (seasontype != "N") {
     init.state <- c(
       init.state,
@@ -827,7 +822,7 @@ etsmodel <- function(
   )
 }
 
-etsTargetFunctionInit <- function(
+etsTargetFunctionInitWrapper <- function(
   par,
   y,
   nstate,
@@ -927,34 +922,32 @@ etsTargetFunctionInit <- function(
 
   env <- new.env()
 
-  res <- .Call(
-    "etsTargetFunctionInit",
-    y = y,
-    nstate = nstate,
-    errortype = switch(errortype, "A" = 1, "M" = 2),
-    trendtype = switch(trendtype, "N" = 0, "A" = 1, "M" = 2),
-    seasontype = switch(seasontype, "N" = 0, "A" = 1, "M" = 2),
-    damped = damped,
-    lowerb = lowerb,
-    upperb = upperb,
-    opt.crit = opt.crit,
-    nmse = as.integer(nmse),
-    bounds = bounds,
-    m = m,
-    optAlpha,
-    optBeta,
-    optGamma,
-    optPhi,
-    givenAlpha,
-    givenBeta,
-    givenGamma,
-    givenPhi,
-    alpha,
-    beta,
-    gamma,
-    phi,
-    env,
-    PACKAGE = "forecast"
+  res <- etsTargetFunctionInit(
+    p_y = y,
+    p_nstate = nstate,
+    p_errortype = switch(errortype, A = 1L, M = 2L),
+    p_trendtype = switch(trendtype, N = 0L, A = 1L, M = 2L),
+    p_seasontype = switch(seasontype, N = 0L, A = 1L, M = 2L),
+    p_damped = damped,
+    p_lower = lowerb,
+    p_upper = upperb,
+    p_opt_crit = opt.crit,
+    p_nmse = as.integer(nmse),
+    p_bounds = bounds,
+    p_m = m,
+    p_optAlpha = optAlpha,
+    p_optBeta = optBeta,
+    p_optGamma = optGamma,
+    p_optPhi = optPhi,
+    p_givenAlpha = givenAlpha,
+    p_givenBeta = givenBeta,
+    p_givenGamma = givenGamma,
+    p_givenPhi = givenPhi,
+    p_alpha = alpha,
+    p_beta = beta,
+    p_gamma = gamma,
+    p_phi = phi,
+    p_rho = env
   )
   res
 }
@@ -1104,7 +1097,7 @@ initstate <- function(y, trendtype, seasontype) {
     y.sa <- y
   }
 
-  maxn <- min(max(10, 2*m), length(y.sa))
+  maxn <- min(max(10, 2 * m), length(y.sa))
   if (trendtype == "N") {
     l0 <- mean(head(y.sa, maxn))
     b0 <- NULL
@@ -1332,8 +1325,6 @@ pegelsresid.C <- function(
   p <- length(init.state)
   x <- numeric(p * (n + 1))
   x[1:p] <- init.state
-  e <- fits <- numeric(n)
-  lik <- 0
   if (!damped) {
     phi <- 1
   }
@@ -1344,38 +1335,30 @@ pegelsresid.C <- function(
     gamma <- 0
   }
 
-  amse <- numeric(nmse)
-  Cout <- .C(
-    "etscalc",
+  res <- .Call(
+    etscalc,
     as.double(y),
-    as.integer(n),
     as.double(x),
     as.integer(m),
-    as.integer(switch(errortype, "A" = 1, "M" = 2)),
-    as.integer(switch(trendtype, "N" = 0, "A" = 1, "M" = 2)),
-    as.integer(switch(seasontype, "N" = 0, "A" = 1, "M" = 2)),
+    switch(errortype, A = 1L, M = 2L),
+    switch(trendtype, N = 0L, A = 1L, M = 2L),
+    switch(seasontype, N = 0L, A = 1L, M = 2L),
     as.double(alpha),
     as.double(beta),
     as.double(gamma),
     as.double(phi),
-    as.double(e),
-    as.double(fits),
-    as.double(lik),
-    as.double(amse),
-    as.integer(nmse),
-    NAOK = TRUE,
-    PACKAGE = "forecast"
+    as.integer(nmse)
   )
   tsp.y <- tsp(y)
-  e <- ts(Cout[[12]])
+  e <- ts(res$e)
   tsp(e) <- tsp.y
 
   list(
-    lik = Cout[[14]],
-    amse = Cout[[15]],
+    lik = res$lik,
+    amse = res$amse,
     e = e,
-    fits = Cout[[13]],
-    states = matrix(Cout[[3]], nrow = n + 1, ncol = p, byrow = TRUE)
+    fits = res$fitted,
+    states = matrix(res$states, nrow = n + 1, ncol = p, byrow = TRUE)
   )
 }
 
@@ -1531,17 +1514,15 @@ hfitted.ets <- function(object, h = 1, ...) {
   n <- length(object$x)
   out <- rep(NA_real_, n)
   for (i in seq_len(n - h + 1)) {
-    out[i + h - 1] <- .C(
-      "etsforecast",
+    out[i + h - 1] <- .Call(
+      etsforecast,
       as.double(object$states[i, ]),
       as.integer(object$m),
-      as.integer(switch(object$components[2], N = 0, A = 1, M = 2)),
-      as.integer(switch(object$components[3], N = 0, A = 1, M = 2)),
+      switch(object$components[2], N = 0L, A = 1L, M = 2L),
+      switch(object$components[3], N = 0L, A = 1L, M = 2L),
       as.double(if (object$components[4] == "FALSE") 1 else object$par["phi"]),
-      as.integer(h),
-      as.double(numeric(h)),
-      PACKAGE = "forecast"
-    )[[7]][h]
+      as.integer(h)
+    )[h]
   }
   out
 }
