@@ -193,20 +193,18 @@ forecast.ets <- function(
   structure(out, class = "forecast")
 }
 
-pegelsfcast.C <- function(h, obj, npaths, level, bootstrap, innov=NULL) {
+pegelsfcast.C <- function(h, obj, npaths, level, bootstrap, innov = NULL) {
   y.paths <- matrix(NA, nrow = npaths, ncol = h)
   obj$lambda <- NULL # No need to transform these here as we do it later.
-  y.f <- .C(
-    "etsforecast",
+  y.f <- .Call(
+    etsforecast,
     as.double(obj$states[length(obj$x) + 1, ]),
     as.integer(obj$m),
-    as.integer(switch(obj$components[2], N = 0, A = 1, M = 2)),
-    as.integer(switch(obj$components[3], N = 0, A = 1, M = 2)),
+    switch(obj$components[2], N = 0L, A = 1L, M = 2L),
+    switch(obj$components[3], N = 0L, A = 1L, M = 2L),
     as.double(if (obj$components[4] == "FALSE") 1 else obj$par["phi"]),
-    as.integer(h),
-    as.double(numeric(h)),
-    PACKAGE = "forecast"
-  )[[7]]
+    as.integer(h)
+  )
   if (abs(y.f[1] + 99999) < 1e-7) {
     stop("Problem with multiplicative damped trend")
   }
@@ -216,7 +214,7 @@ pegelsfcast.C <- function(h, obj, npaths, level, bootstrap, innov=NULL) {
     level = level,
     npaths = npaths,
     bootstrap = bootstrap,
-    innov = innov,
+    innov = innov
   )
   lower <- hilo$lower
   upper <- hilo$upper
@@ -270,7 +268,7 @@ class1 <- function(
   Fj <- diag(p)
   cj <- numeric(h - 1)
   if (h > 1) {
-    for (i in 1:(h - 1)) {
+    for (i in seq_len(h - 1)) {
       mu[i] <- H %*% Fj %*% last.state
       cj[i] <- H %*% Fj %*% G
       Fj <- Fj %*% F
@@ -340,7 +338,7 @@ class3 <- function(
   G21 <- G2 %x% G1
   K <- (G2 %x% F1) + (F2 %x% G1)
   mu <- var <- numeric(h)
-  for (i in 1:h) {
+  for (i in seq_len(h)) {
     mu[i] <- H1 %*% Mh %*% t(H2)
     var[i] <- (1 + sigma2) * H21 %*% Vh %*% t(H21) + sigma2 * mu[i]^2
     vecMh <- c(Mh)
