@@ -4,8 +4,16 @@
 # Author: srazbash
 ###############################################################################
 
-makeTBATSFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=NULL, k.vector=NULL, gamma.bold.matrix=NULL, ar.coefs=NULL, ma.coefs=NULL) {
-
+makeTBATSFMatrix <- function(
+  alpha,
+  beta = NULL,
+  small.phi = NULL,
+  seasonal.periods = NULL,
+  k.vector = NULL,
+  gamma.bold.matrix = NULL,
+  ar.coefs = NULL,
+  ma.coefs = NULL
+) {
   # 1. Alpha Row
   F <- matrix(1, nrow = 1, ncol = 1)
   if (!is.null(beta)) {
@@ -56,27 +64,40 @@ makeTBATSFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=
     # Make the A matrix
     A <- matrix(0, tau, tau)
     last.pos <- 0
-    for (i in 1:length(k.vector)) {
+    for (i in seq_along(k.vector)) {
       if (seasonal.periods[i] != 2) {
-        C <- .Call("makeCIMatrix", k_s = as.integer(k.vector[i]), m_s = as.double(seasonal.periods[i]), PACKAGE = "forecast")
+        C <- makeCIMatrix(
+          k = as.integer(k.vector[i]),
+          m = as.double(seasonal.periods[i])
+        )
       } else {
         C <- matrix(0, 1, 1)
       }
-      S <- .Call("makeSIMatrix", k_s = as.integer(k.vector[i]), m_s = as.double(seasonal.periods[i]), PACKAGE = "forecast")
+      S <- makeSIMatrix(
+        k = as.integer(k.vector[i]),
+        m = as.double(seasonal.periods[i])
+      )
 
       # C <- matrix(0,k.vector[i],k.vector[i])
-      # for(j in 1:k.vector[i]) {
+      # for(j in seq_len(k.vector[i])) {
       # 	l <- round((2*pi*j/seasonal.periods[i]), digits=15)
       # 	C[j,j] <- cos(l)
       # }
       # S <- matrix(0,k.vector[i],k.vector[i])
-      # for(j in 1:k.vector[i]) {
+      # for(j in seq_len(k.vector[i])) {
       # 	S[j,j] <- sin(2*pi*j/seasonal.periods[i])
       # }
       # print(C)
       # print(S)
-      Ai <- .Call("makeAIMatrix", C_s = C, S_s = S, k_s = as.integer(k.vector[i]), PACKAGE = "forecast")
-      A[(last.pos + 1):(last.pos + (2 * k.vector[i])), (last.pos + 1):(last.pos + (2 * k.vector[i]))] <- Ai
+      Ai <- makeAIMatrix(
+        C = C,
+        S = S,
+        k = as.integer(k.vector[i])
+      )
+      A[
+        (last.pos + 1):(last.pos + (2 * k.vector[i])),
+        (last.pos + 1):(last.pos + (2 * k.vector[i]))
+      ] <- Ai
       last.pos <- last.pos + (2 * k.vector[i])
     }
     seasonal.row <- cbind(seasonal.row, A)
@@ -137,12 +158,12 @@ makeTBATSFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=
     ma.rows <- cbind(ma.rows, ma.part)
     F <- rbind(F, ma.rows)
   }
-  return(F)
+  F
 }
 
 # makeWMatrix <- function(small.phi=NULL, seasonal.periods=NULL, ar.coefs=NULL, ma.coefs=NULL) {
 #
-# 	the.list <- .Call("makeBATSWMatrix", smallPhi_s = small.phi, sPeriods_s = as.integer(seasonal.periods), arCoefs_s = ar.coefs, maCoefs_s = ma.coefs, PACKAGE = "forecast")
+# 	the.list <- makeBATSWMatrix(smallPhi = small.phi, sPeriods = as.integer(seasonal.periods), arCoefs = ar.coefs, maCoefs = ma.coefs)
 #
 #
 # 	return(the.list)
@@ -150,13 +171,20 @@ makeTBATSFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=
 # }
 
 # makeGMatrix <- function(alpha, beta=NULL, gamma.vector=NULL, seasonal.periods=NULL, p=0, q=0) {
-# 	li <- .Call("makeBATSGMatrix", alpha, beta, gamma.vector, as.integer(seasonal.periods), as.integer(p), as.integer(q), PACKAGE="forecast")
+# 	li <- makeBATSGMatrix(alpha, beta, gamma.vector, as.integer(seasonal.periods), as.integer(p), as.integer(q))
 #
 # 	return(li)
 # }
 
-makeFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=NULL, gamma.bold.matrix=NULL, ar.coefs=NULL, ma.coefs=NULL) {
-
+makeFMatrix <- function(
+  alpha,
+  beta = NULL,
+  small.phi = NULL,
+  seasonal.periods = NULL,
+  gamma.bold.matrix = NULL,
+  ar.coefs = NULL,
+  ma.coefs = NULL
+) {
   # 1. Alpha Row
   F <- matrix(1, nrow = 1, ncol = 1)
   if (!is.null(beta)) {
@@ -220,7 +248,10 @@ makeFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=NULL,
         Ai <- rbind(a.row.one, a.row.two)
         A <- rbind(A, matrix(0, nrow = dim(Ai)[1], ncol = old.A.columns))
         A <- cbind(A, matrix(0, nrow = dim(A)[1], ncol = dim(Ai)[2]))
-        A[((old.A.rows + 1):(old.A.rows + dim(Ai)[1])), ((old.A.columns + 1):(old.A.columns + dim(Ai)[2]))] <- Ai
+        A[
+          ((old.A.rows + 1):(old.A.rows + dim(Ai)[1])),
+          ((old.A.columns + 1):(old.A.columns + dim(Ai)[2]))
+        ] <- Ai
       }
     }
     seasonal.row <- cbind(seasonal.row, A)
@@ -281,26 +312,41 @@ makeFMatrix <- function(alpha, beta=NULL, small.phi=NULL, seasonal.periods=NULL,
     ma.rows <- cbind(ma.rows, ma.part)
     F <- rbind(F, ma.rows)
   }
-  return(F)
+  F
 }
 
-makeXMatrix <- function(l, b=NULL, s.vector=NULL, d.vector=NULL, epsilon.vector=NULL) {
+makeXMatrix <- function(
+  l,
+  b = NULL,
+  s.vector = NULL,
+  d.vector = NULL,
+  epsilon.vector = NULL
+) {
   x.transpose <- matrix(l, nrow = 1, ncol = 1)
   if (!is.null(b)) {
     x.transpose <- cbind(x.transpose, matrix(b, nrow = 1, ncol = 1))
   }
   if (!is.null(s.vector)) {
-    x.transpose <- cbind(x.transpose, matrix(s.vector, nrow = 1, ncol = length(s.vector)))
+    x.transpose <- cbind(
+      x.transpose,
+      matrix(s.vector, nrow = 1, ncol = length(s.vector))
+    )
   }
 
   if (!is.null(d.vector)) {
-    x.transpose <- cbind(x.transpose, matrix(d.vector, nrow = 1, ncol = length(d.vector)))
+    x.transpose <- cbind(
+      x.transpose,
+      matrix(d.vector, nrow = 1, ncol = length(d.vector))
+    )
   }
 
   if (!is.null(epsilon.vector)) {
-    x.transpose <- cbind(x.transpose, matrix(epsilon.vector, nrow = 1, ncol = length(epsilon.vector)))
+    x.transpose <- cbind(
+      x.transpose,
+      matrix(epsilon.vector, nrow = 1, ncol = length(epsilon.vector))
+    )
   }
 
   x <- t(x.transpose)
-  return(list(x = x, x.transpose = x.transpose))
+  list(x = x, x.transpose = x.transpose)
 }
