@@ -5,32 +5,30 @@
 # size set to average of number of inputs and number of outputs: (p+P+1)/2
 # if xreg is included then size = (p+P+ncol(xreg)+1)/2
 
-
 #' Neural Network Time Series Forecasts
 #'
 #' Feed-forward neural networks with a single hidden layer and lagged inputs
 #' for forecasting univariate time series.
 #'
-#' A feed-forward neural network is fitted with lagged values of \code{y} as
-#' inputs and a single hidden layer with \code{size} nodes. The inputs are for
-#' lags 1 to \code{p}, and lags \code{m} to \code{mP} where
-#' \code{m=frequency(y)}. If \code{xreg} is provided, its columns are also
-#' used as inputs. If there are missing values in \code{y} or
-#' \code{xreg}, the corresponding rows (and any others which depend on them as
-#' lags) are omitted from the fit. A total of \code{repeats} networks are
-#' fitted, each with random starting weights. These are then averaged when
-#' computing forecasts. The network is trained for one-step forecasting.
-#' Multi-step forecasts are computed recursively.
+#' A feed-forward neural network is fitted with lagged values of `y` as inputs
+#' and a single hidden layer with `size` nodes. The inputs are for lags 1 to
+#' `p`, and lags `m` to `mP` where `m = frequency(y)`. If `xreg` is provided,
+#' its columns are also used as inputs. If there are missing values in `y` or
+#' `xreg`, the corresponding rows (and any others which depend on them as lags)
+#' are omitted from the fit. A total of `repeats` networks are fitted, each
+#' with random starting weights. These are then averaged when computing
+#' forecasts. The network is trained for one-step forecasting. Multi-step
+#' forecasts are computed recursively.
 #'
 #' For non-seasonal data, the fitted model is denoted as an NNAR(p,k) model,
 #' where k is the number of hidden nodes. This is analogous to an AR(p) model
 #' but with nonlinear functions. For seasonal data, the fitted model is called
-#' an NNAR(p,P,k)[m] model, which is analogous to an ARIMA(p,0,0)(P,0,0)[m]
+#' an NNAR(p,P,k)\[m\] model, which is analogous to an ARIMA(p,0,0)(P,0,0)\[m\]
 #' model but with nonlinear functions.
 #'
 #' @aliases print.nnetar print.nnetarmodels
 #'
-#' @param y A numeric vector or time series of class \code{ts}.
+#' @inheritParams Arima
 #' @param p Embedding dimension for non-seasonal time series. Number of
 #' non-seasonal lags used as inputs. For non-seasonal time series, the default
 #' is the optimal number of lags (according to the AIC) for a linear AR(p)
@@ -43,29 +41,30 @@
 #' number of input nodes (including external regressors, if given) plus 1.
 #' @param repeats Number of networks to fit with different random starting
 #' weights. These are then averaged when producing forecasts.
-#' @param xreg Optionally, a vector or matrix of external regressors, which
-#' must have the same number of rows as \code{y}. Must be numeric.
-#' @param model Output from a previous call to \code{nnetar}. If model is
-#' passed, this same model is fitted to \code{y} without re-estimating any
+#' @param model Output from a previous call to `nnetar`. If model is
+#' passed, this same model is fitted to `y` without re-estimating any
 #' parameters.
 #' @param subset Optional vector specifying a subset of observations to be used
 #' in the fit. Can be an integer index vector or a logical vector the same
-#' length as \code{y}. All observations are used by default.
-#' @param scale.inputs If TRUE, inputs are scaled by subtracting the column
-#' means and dividing by their respective standard deviations. If \code{lambda}
-#' is not \code{NULL}, scaling is applied after Box-Cox transformation.
-#' @param x Deprecated. Included for backwards compatibility.
-#' @param \dots Other arguments passed to \code{\link[nnet]{nnet}} for
-#' \code{nnetar}.
-#' @inheritParams forecast.ts
+#' length as `y`. All observations are used by default.
+#' @param scale.inputs If `TRUE`, inputs are scaled by subtracting the column
+#' means and dividing by their respective standard deviations. If `lambda`
+#' is not `NULL`, scaling is applied after Box-Cox transformation.
+#' @param parallel If `TRUE`, then the specification search is done in parallel
+#' via [parallel::parLapply()]. This can give a significant speedup on
+#' multicore machines.
+#' @param num.cores Allows the user to specify the amount of parallel processes
+#' to be used if `parallel = TRUE`. If `NULL`, then the number of logical cores
+#' is automatically detected and all available cores are used.
+#' @param ... Other arguments passed to [nnet::nnet()] for `nnetar`.
 #'
-#' @return Returns an object of class "\code{nnetar}".
+#' @return Returns an object of class `nnetar`.
 #'
-#' The function \code{summary} is used to obtain and print a summary of the
+#' The function `summary` is used to obtain and print a summary of the
 #' results.
 #'
-#' The generic accessor functions \code{fitted.values} and \code{residuals}
-#' extract useful features of the value returned by \code{nnetar}.
+#' The generic accessor functions `fitted.values` and `residuals`
+#' extract useful features of the value returned by `nnetar`.
 #'
 #' \item{model}{A list containing information about the fitted model}
 #' \item{method}{The name of the forecasting method as a character string}
@@ -83,22 +82,37 @@
 #' plot(fcast)
 #'
 #' ## Arguments can be passed to nnet()
-#' fit <- nnetar(lynx, decay=0.5, maxit=150)
+#' fit <- nnetar(lynx, decay = 0.5, maxit = 150)
 #' plot(forecast(fit))
 #' lines(lynx)
 #'
 #' ## Fit model to first 100 years of lynx data
-#' fit <- nnetar(window(lynx,end=1920), decay=0.5, maxit=150)
-#' plot(forecast(fit,h=14))
+#' fit <- nnetar(window(lynx, end = 1920), decay = 0.5, maxit = 150)
+#' plot(forecast(fit, h = 14))
 #' lines(lynx)
 #'
 #' ## Apply fitted model to later data, including all optional arguments
-#' fit2 <- nnetar(window(lynx,start=1921), model=fit)
+#' fit2 <- nnetar(window(lynx, start = 1921), model = fit)
 #'
 #' @export
-nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NULL, subset=NULL, scale.inputs=TRUE, x=y, ...) {
+nnetar <- function(
+  y,
+  p,
+  P = 1,
+  size = NULL,
+  repeats = 20,
+  xreg = NULL,
+  lambda = NULL,
+  model = NULL,
+  subset = NULL,
+  scale.inputs = TRUE,
+  parallel = FALSE,
+  num.cores = 2,
+  x = y,
+  ...
+) {
   useoldmodel <- FALSE
-  yname <- deparse(substitute(y))
+  yname <- deparse1(substitute(y))
   if (!is.null(model)) {
     # Use previously fitted model
     useoldmodel <- TRUE
@@ -111,10 +125,17 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
     m <- max(round(frequency(model$x)), 1L)
     minlength <- max(c(model$p, model$P * m)) + 1
     if (length(x) < minlength) {
-      stop(paste("Series must be at least of length", minlength, "to use fitted model"))
+      stop(paste(
+        "Series must be at least of length",
+        minlength,
+        "to use fitted model"
+      ))
     }
     if (tsp(as.ts(x))[3] != m) {
-      warning(paste("Data frequency doesn't match fitted model, coercing to frequency =", m))
+      warning(paste(
+        "Data frequency doesn't match fitted model, coercing to frequency =",
+        m
+      ))
       x <- ts(x, frequency = m)
     }
     # Check xreg
@@ -131,7 +152,7 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
     size <- model$size
     p <- model$p
     P <- model$P
-    if (p == 0 && P == 0){
+    if (p == 0 && P == 0) {
       stop("Both p = 0 and P = 0 in supplied 'model' object")
     }
     if (P > 0) {
@@ -142,23 +163,28 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
     if (is.null(model$scalex)) {
       scale.inputs <- FALSE
     }
-  } else {                 # when not using an old model
+  } else {
+    # when not using an old model
     if (length(y) < 3) {
       stop("Not enough data to fit a model")
     }
     # Check for constant data in time series
     constant_data <- is.constant(na.interp(x))
-    if (constant_data){
-      warning("Constant data, setting p=1, P=0, lambda=NULL, scale.inputs=FALSE")
+    if (constant_data) {
+      warning(
+        "Constant data, setting p=1, P=0, lambda=NULL, scale.inputs=FALSE"
+      )
       scale.inputs <- FALSE
       lambda <- NULL
       p <- 1
       P <- 0
     }
     ## Check for constant data in xreg
-    if (!is.null(xreg)){
-      constant_xreg <- any(apply(as.matrix(xreg), 2, function(x) is.constant(na.interp(x))))
-      if (constant_xreg){
+    if (!is.null(xreg)) {
+      constant_xreg <- any(apply(as.matrix(xreg), 2, function(x) {
+        is.constant(na.interp(x))
+      }))
+      if (constant_xreg) {
         warning("Constant xreg column, setting scale.inputs=FALSE")
         scale.inputs <- FALSE
       }
@@ -166,7 +192,7 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   }
 
   # Check for NAs in x
-  if (any(is.na(x))) {
+  if (anyNA(x)) {
     warning("Missing values in x, omitting rows")
   }
 
@@ -190,8 +216,7 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   if (scale.inputs) {
     if (useoldmodel) {
       scalex <- model$scalex
-    }
-    else {
+    } else {
       tmpx <- scale(xx[xsub], center = TRUE, scale = TRUE)
       scalex <- list(
         center = attr(tmpx, "scaled:center"),
@@ -210,15 +235,14 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
       stop("Number of rows in xreg does not match series length")
     }
     # Check for NAs in xreg
-    if (any(is.na(xreg))) {
+    if (anyNA(xreg)) {
       warning("Missing values in xreg, omitting rows")
     }
     # Scale xreg
     if (scale.inputs) {
       if (useoldmodel) {
         scalexreg <- model$scalexreg
-      }
-      else {
+      } else {
         tmpx <- scale(xxreg[xsub, ], center = TRUE, scale = TRUE)
         scalexreg <- list(
           center = attr(tmpx, "scaled:center"),
@@ -239,8 +263,10 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
       }
       # For non-seasonal data also use default calculation for p if that
       # argument is 0, but issue a warning
-      if (p == 0){
-        warning("Cannot set p = 0 for non-seasonal data; using default calculation for p")
+      if (p == 0) {
+        warning(
+          "Cannot set p = 0 for non-seasonal data; using default calculation for p"
+        )
         p <- max(length(ar(na.interp(xx))$ar), 1)
       }
       if (p >= n) {
@@ -261,7 +287,7 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
         }
         p <- max(length(ar(x.sa)$ar), 1)
       }
-      if (p == 0 && P == 0){
+      if (p == 0 && P == 0) {
         stop("'p' and 'P' cannot both be zero")
       }
       if (p >= n) {
@@ -283,11 +309,12 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   nlag <- length(lags)
   y <- xx[-(1:maxlag)]
   lags.X <- matrix(NA_real_, ncol = nlag, nrow = n - maxlag)
-  for (i in 1:nlag)
+  for (i in seq_len(nlag)) {
     lags.X[, i] <- xx[(maxlag - lags[i] + 1):(n - lags[i])]
+  }
   # Add xreg into lagged matrix
   lags.X <- cbind(lags.X, xxreg[-(1:maxlag), , drop = FALSE])
-  if (missing(size)) {
+  if (is.null(size)) {
     size <- round((NCOL(lags.X) + 1) / 2)
   }
   # Remove missing values if present
@@ -295,14 +322,29 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   ## Remove values not in subset
   j <- j & xsub[-(1:maxlag)]
   ## Stop if there's no data to fit (e.g. due to NAs or NaNs)
-  if (NROW(lags.X[j,, drop=FALSE]) == 0) {
+  if (NROW(lags.X[j, , drop = FALSE]) == 0) {
     stop("No data to fit (possibly due to NA or NaN)")
   }
   ## Fit average ANN.
   if (useoldmodel) {
-    fit <- oldmodel_avnnet(lags.X[j, , drop = FALSE], y[j], size = size, model)
+    fit <- oldmodel_avnnet(
+      lags.X[j, , drop = FALSE],
+      y[j],
+      size = size,
+      model = model,
+      parallel = parallel,
+      num.cores = num.cores
+    )
   } else {
-    fit <- avnnet(lags.X[j, , drop=FALSE], y[j], size = size, repeats = repeats, ...)
+    fit <- avnnet(
+      lags.X[j, , drop = FALSE],
+      y[j],
+      size = size,
+      repeats = repeats,
+      parallel = parallel,
+      num.cores = num.cores,
+      ...
+    )
   }
   # Return results
   out <- list()
@@ -315,15 +357,15 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   out$size <- size
   out$xreg <- xreg
   out$lambda <- lambda
-  out$subset <- (1:length(x))[xsub]
+  out$subset <- seq_along(x)[xsub]
   out$model <- fit
   out$nnetargs <- list(...)
   if (useoldmodel) {
     out$nnetargs <- model$nnetargs
   }
-  if (NROW(lags.X[j,, drop=FALSE]) == 1){
+  if (NROW(lags.X[j, , drop = FALSE]) == 1) {
     fits <- c(rep(NA_real_, maxlag), mean(sapply(fit, predict)))
-  } else{
+  } else {
     fits <- c(rep(NA_real_, maxlag), rowMeans(sapply(fit, predict)))
   }
   if (scale.inputs) {
@@ -339,41 +381,76 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   out$residuals <- out$x - out$fitted
   out$lags <- lags
   out$series <- yname
-  out$method <- paste("NNAR(", p, sep = "")
+  out$method <- paste0("NNAR(", p)
   if (P > 0) {
-    out$method <- paste(out$method, ",", P, sep = "")
+    out$method <- paste0(out$method, ",", P)
   }
-  out$method <- paste(out$method, ",", size, ")", sep = "")
+  out$method <- paste0(out$method, ",", size, ")")
   if (P > 0) {
-    out$method <- paste(out$method, "[", m, "]", sep = "")
+    out$method <- paste0(out$method, "[", m, "]")
   }
   out$call <- match.call()
-  return(structure(out, class = c("nnetar")))
+  structure(out, class = c("fc_model", "nnetar"))
 }
 
 # Aggregate several neural network models
-avnnet <- function(x, y, repeats, linout=TRUE, trace=FALSE, ...) {
-  mods <- list()
-  for (i in 1:repeats)
+avnnet <- function(
+  x,
+  y,
+  repeats,
+  parallel,
+  num.cores,
+  linout = TRUE,
+  trace = FALSE,
+  ...
+) {
+  if (parallel) {
+    if (is.null(num.cores)) {
+      num.cores <- detectCores()
+    }
+    cl <- makeCluster(num.cores)
+    on.exit(stopCluster(cl), add = TRUE)
+    mods <- parLapply(cl, seq_len(repeats), function(i) {
+      nnet::nnet(x = x, y = y, linout = linout, trace = trace, ...)
+    })
+    return(structure(mods, class = "nnetarmodels"))
+  }
+
+  mods <- vector("list", repeats)
+  for (i in seq_len(repeats)) {
     mods[[i]] <- nnet::nnet(x, y, linout = linout, trace = trace, ...)
-  return(structure(mods, class = "nnetarmodels"))
+  }
+  structure(mods, class = "nnetarmodels")
 }
 
 # Fit old model to new data
-oldmodel_avnnet <- function(x, y, size, model) {
+oldmodel_avnnet <- function(x, y, size, model, parallel, num.cores) {
   repeats <- length(model$model)
   args <- list(x = x, y = y, size = size, linout = 1, trace = FALSE)
   # include additional nnet arguments
   args <- c(args, model$nnetargs)
   # set iterations to zero (i.e. weights stay fixed)
   args$maxit <- 0
-  mods <- list()
-  for (i in 1:repeats)
-  {
+
+  if (parallel) {
+    if (is.null(num.cores)) {
+      num.cores <- detectCores()
+    }
+    cl <- makeCluster(num.cores)
+    on.exit(stopCluster(cl), add = TRUE)
+    mods <- parLapply(cl, seq_len(repeats), function(i) {
+      args$Wts <- model$model[[i]]$wts
+      do.call(nnet::nnet, args)
+    })
+    return(structure(mods, class = "nnetarmodels"))
+  }
+
+  mods <- vector("list", repeats)
+  for (i in seq_len(repeats)) {
     args$Wts <- model$model[[i]]$wts
     mods[[i]] <- do.call(nnet::nnet, args)
   }
-  return(structure(mods, class = "nnetarmodels"))
+  structure(mods, class = "nnetarmodels")
 }
 
 #' @export
@@ -383,7 +460,6 @@ print.nnetarmodels <- function(x, ...) {
 }
 
 
-
 #' Forecasting using neural network models
 #'
 #' Returns forecasts and other information for univariate neural network
@@ -395,100 +471,67 @@ print.nnetarmodels <- function(x, ...) {
 #' could lead to misleadingly small values. It is possible to use out-of-sample
 #' residuals to ameliorate this, see examples.
 #'
-#' @param object An object of class "\code{nnetar}" resulting from a call to
-#' \code{\link{nnetar}}.
-#' @param h Number of periods for forecasting. If \code{xreg} is used, \code{h}
-#' is ignored and the number of forecast periods is set to the number of rows
-#' of \code{xreg}.
-#' @param PI If TRUE, prediction intervals are produced, otherwise only point
-#' forecasts are calculated. If \code{PI} is FALSE, then \code{level},
-#' \code{fan}, \code{bootstrap} and \code{npaths} are all ignored.
-#' @param level Confidence level for prediction intervals.
-#' @param fan If \code{TRUE}, level is set to \code{seq(51,99,by=3)}. This is
-#' suitable for fan plots.
-#' @param xreg Future values of external regressor variables.
-#' @param bootstrap If \code{TRUE}, then prediction intervals computed using
-#' simulations with resampled residuals rather than normally distributed
-#' errors. Ignored if \code{innov} is not \code{NULL}.
-#' @param npaths Number of sample paths used in computing simulated prediction
-#' intervals.
+#' @inheritParams forecast.Arima
+#' @param object An object of class `nnetar` resulting from a call to
+#' [nnetar()].
+#' @param PI If `TRUE`, prediction intervals are produced, otherwise only point
+#' forecasts are calculated. If `PI` is `FALSE`, then `level`,
+#' `fan`, `bootstrap` and `npaths` are all ignored.
 #' @param innov Values to use as innovations for prediction intervals. Must be
-#' a matrix with \code{h} rows and \code{npaths} columns (vectors are coerced
-#' into a matrix). If present, \code{bootstrap} is ignored.
-#' @param ... Additional arguments passed to \code{\link{simulate.nnetar}}
-#' @inheritParams forecast.ts
-#'
-#' @return An object of class "\code{forecast}".
-#'
-#' The function \code{summary} is used to obtain and print a summary of the
-#' results, while the function \code{plot} produces a plot of the forecasts and
-#' prediction intervals.
-#'
-#' The generic accessor functions \code{fitted.values} and \code{residuals}
-#' extract useful features of the value returned by \code{forecast.nnetar}.
-#'
-#' An object of class "\code{forecast}" is a list containing at least the
-#' following elements:
-#'   \item{model}{A list containing information about the fitted model}
-#'   \item{method}{The name of the forecasting method as a character string}
-#'   \item{mean}{Point forecasts as a time series}
-#'   \item{lower}{Lower limits for prediction intervals}
-#'   \item{upper}{Upper limits for prediction intervals}
-#'   \item{level}{The confidence values associated with the prediction intervals}
-#'   \item{x}{The original time series (either \code{object} itself or the time series
-#'            used to create the model stored as \code{object}).}
-#'   \item{xreg}{The external regressors used in fitting (if given).}
-#'   \item{residuals}{Residuals from the fitted model. That is x minus fitted values.}
-#'   \item{fitted}{Fitted values (one-step forecasts)}
-#'   \item{...}{Other arguments}
-#'
+#' a matrix with `h` rows and `npaths` columns (vectors are coerced
+#' into a matrix). If present, `bootstrap` is ignored.
+#' @param ... Additional arguments passed to [simulate.nnetar()].
+#' @return An object of class `forecast`.
+#' @inheritSection forecast.ts forecast class
 #' @author Rob J Hyndman and Gabriel Caceres
-#' @seealso \code{\link{nnetar}}.
+#' @seealso [nnetar()].
 #' @keywords ts
 #' @examples
 #' ## Fit & forecast model
-#' fit <- nnetar(USAccDeaths, size=2)
-#' fcast <- forecast(fit, h=20)
+#' fit <- nnetar(USAccDeaths, size = 2)
+#' fcast <- forecast(fit, h = 20)
 #' plot(fcast)
 #'
 #' \dontrun{
 #' ## Include prediction intervals in forecast
-#' fcast2 <- forecast(fit, h=20, PI=TRUE, npaths=100)
+#' fcast2 <- forecast(fit, h = 20, PI = TRUE, npaths = 100)
 #' plot(fcast2)
 #'
 #' ## Set up out-of-sample innovations using cross-validation
-#' fit_cv <- CVar(USAccDeaths,  size=2)
-#' res_sd <- sd(fit_cv$residuals, na.rm=TRUE)
-#' myinnovs <- rnorm(20*100, mean=0, sd=res_sd)
+#' fit_cv <- CVar(USAccDeaths, size = 2)
+#' res_sd <- sd(fit_cv$residuals, na.rm = TRUE)
+#' myinnovs <- rnorm(20 * 100, mean = 0, sd = res_sd)
 #' ## Forecast using new innovations
-#' fcast3 <- forecast(fit, h=20, PI=TRUE, npaths=100, innov=myinnovs)
+#' fcast3 <- forecast(fit, h = 20, PI = TRUE, npaths = 100, innov = myinnovs)
 #' plot(fcast3)
 #' }
-
 #'
 #' @export
-forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI=FALSE, level=c(80, 95), fan=FALSE, xreg=NULL, lambda=object$lambda, bootstrap=FALSE, npaths=1000, innov=NULL, ...) {
-  #  require(nnet)
+forecast.nnetar <- function(
+  object,
+  h = if (object$m > 1) 2 * object$m else 10,
+  PI = FALSE,
+  level = c(80, 95),
+  fan = FALSE,
+  xreg = NULL,
+  lambda = object$lambda,
+  bootstrap = FALSE,
+  npaths = 1000,
+  innov = NULL,
+  ...
+) {
   out <- object
   tspx <- tsp(out$x)
-  #
-  if (fan) {
-    level <- seq(51, 99, by = 3)
-  } else {
-    if (min(level) > 0 && max(level) < 1) {
-      level <- 100 * level
-    } else if (min(level) < 0 || max(level) > 99.99) {
-      stop("Confidence limit out of range")
-    }
-  }
+  level <- getConfLevel(level, fan)
   # Check if xreg was used in fitted model
   if (is.null(object$xreg)) {
     if (!is.null(xreg)) {
-      warning("External regressors were not used in fitted model, xreg will be ignored")
+      warning(
+        "External regressors were not used in fitted model, xreg will be ignored"
+      )
     }
     xreg <- NULL
-  }
-  else {
+  } else {
     if (is.null(xreg)) {
       stop("No external regressors provided")
     }
@@ -496,8 +539,10 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
     if (NCOL(xreg) != NCOL(object$xreg)) {
       stop("Number of external regressors does not match fitted model")
     }
-    if(!identical(colnames(xreg), colnames(object$xreg))){
-      warning("xreg contains different column names from the xreg used in training. Please check that the regressors are in the same order.")
+    if (!identical(colnames(xreg), colnames(object$xreg))) {
+      warning(
+        "xreg contains different column names from the xreg used in training. Please check that the regressors are in the same order."
+      )
     }
     h <- NROW(xreg)
   }
@@ -512,7 +557,11 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
   if (!is.null(object$scalex)) {
     xx <- scale(xx, center = object$scalex$center, scale = object$scalex$scale)
     if (!is.null(xreg)) {
-      xxreg <- scale(xreg, center = object$scalexreg$center, scale = object$scalexreg$scale)
+      xxreg <- scale(
+        xreg,
+        center = object$scalexreg$center,
+        scale = object$scalexreg$scale
+      )
     }
   }
 
@@ -521,13 +570,13 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
   maxlag <- max(lags)
   flag <- rev(tail(xx, n = maxlag))
   # Iterative 1-step forecast
-  for (i in 1:h)
-  {
+  for (i in seq_len(h)) {
     newdata <- c(flag[lags], xxreg[i, ])
-    if (any(is.na(newdata))) {
-      stop("I can't forecast when there are missing values near the end of the series.")
+    if (anyNA(newdata)) {
+      fcast[i] <- NA_real_
+    } else {
+      fcast[i] <- mean(sapply(object$model, predict, newdata = newdata))
     }
-    fcast[i] <- mean(sapply(object$model, predict, newdata = newdata))
     flag <- c(fcast[i], flag[-maxlag])
   }
   # Re-scale point forecasts
@@ -542,31 +591,22 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
   }
   # Compute prediction intervals using simulations
   if (isTRUE(PI)) {
-    nint <- length(level)
-    sim <- matrix(NA, nrow = npaths, ncol = h)
-    if (!is.null(innov)) {
-      if (length(innov) != h * npaths) {
-        stop("Incorrect number of innovations, need h*npaths values")
-      }
-      innov <- matrix(innov, nrow = h, ncol = npaths)
-      bootstrap <- FALSE
-    }
-    for (i in 1:npaths)
-      sim[i, ] <- simulate(object, nsim = h, bootstrap = bootstrap, xreg = xreg, lambda = lambda, innov = innov[, i], ...)
-    lower <- apply(sim, 2, quantile, 0.5 - level / 200, type = 8, na.rm = TRUE)
-    upper <- apply(sim, 2, quantile, 0.5 + level / 200, type = 8, na.rm = TRUE)
-    if (nint > 1L) {
-      lower <- ts(t(lower))
-      upper <- ts(t(upper))
-    }
-    else {
-      lower <- ts(matrix(lower, ncol = 1L))
-      upper <- ts(matrix(upper, ncol = 1L))
-    }
+    hilo <- simulate_forecast(
+      object = object,
+      h = h,
+      level = level,
+      npaths = npaths,
+      bootstrap = bootstrap,
+      innov = innov,
+      xreg = xreg,
+      lambda = lambda,
+      ...
+    )
+    lower <- ts(hilo$lower)
+    upper <- ts(hilo$upper)
     out$lower <- future_msts(out$x, lower)
     out$upper <- future_msts(out$x, upper)
-  }
-  else {
+  } else {
     level <- NULL
     lower <- NULL
     upper <- NULL
@@ -574,17 +614,16 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
   out$mean <- future_msts(out$x, fcast)
   out$level <- level
 
-  return(structure(out, class = "forecast"))
+  structure(out, class = "forecast")
 }
 
 #' @rdname fitted.Arima
 #' @export
-fitted.nnetar <- function(object, h=1, ...) {
+fitted.nnetar <- function(object, h = 1, ...) {
   if (h == 1) {
-    return(object$fitted)
-  }
-  else {
-    return(hfitted(object = object, h = h, FUN = "nnetar", ...))
+    object$fitted
+  } else {
+    hfitted(object = object, h = h, FUN = "nnetar", ...)
   }
 }
 
@@ -597,8 +636,10 @@ print.nnetar <- function(x, digits = max(3, getOption("digits") - 3), ...) {
   print(x$call)
   print(x$model)
   cat(
-    "\nsigma^2 estimated as ", format(mean(residuals(x) ^ 2, na.rm = TRUE), digits = digits),
-    "\n", sep = ""
+    "\nsigma^2 estimated as ",
+    format(mean(residuals(x)^2, na.rm = TRUE), digits = digits),
+    "\n",
+    sep = ""
   )
   invisible(x)
 }
@@ -617,9 +658,9 @@ is.nnetarmodels <- function(x) {
 
 # Scale a univariate time series
 #' @export
-scale.ts <- function(x, center=TRUE, scale=TRUE) {
+scale.ts <- function(x, center = TRUE, scale = TRUE) {
   tspx <- tsp(x)
   x <- as.ts(scale.default(x, center = center, scale = scale))
   tsp(x) <- tspx
-  return(x)
+  x
 }
