@@ -351,15 +351,8 @@ From %s(): %s
 
 # Adjusted from robjhyndman/tsfeatures
 seas.heuristic <- function(x) {
-  if (inherits(x, "msts")) {
-    msts <- attributes(x)$msts
-    nperiods <- length(msts)
-  } else if (is.ts(x)) {
-    msts <- frequency(x)
-    nperiods <- msts > 1
-    season <- 0
-  } else {
-    stop("The object provided must be a time-series object (`msts` or `ts`)")
+  if (!inherits(x, "msts") && !is.ts(x)) {
+    stop("The object provided must be a time-series object `msts` or `ts`)")
   }
   season <- NA
   stlfit <- mstl(x)
@@ -372,7 +365,7 @@ seas.heuristic <- function(x) {
   nseas <- NCOL(seasonal)
   if (nseas > 0) {
     season <- numeric(nseas)
-    for (i in seq(nseas)) {
+    for (i in seq_len(nseas)) {
       season[i] <- max(
         0,
         min(1, 1 - vare / var(remainder + seasonal[, i], na.rm = TRUE))
@@ -486,7 +479,6 @@ ocsb.test <- function(
   # Estimate maxlag
   if (maxlag > 0) {
     if (lag.method != "fixed") {
-      tmp <- vector("list", maxlag + 1)
       fits <- lapply(seq_len(maxlag), function(lag) fitOCSB(x, lag, maxlag))
       icvals <- unlist(switch(
         lag.method,
