@@ -152,8 +152,10 @@ void EtsTargetFunction::eval(const double* p_par, int p_par_length) {
 
 	for(int i=0; i <= p*this->y.size(); i++) state.push_back(0);
 
-	etscalc(&this->y[0], &this->n, &this->state[0], &this->m, &this->errortype, &this->trendtype, &this->seasontype,
-			&this->alpha, &this->beta, &this->gamma, &this->phi, &this->e[0], &this->fits[0], &this->lik, &this->amse[0], &this->nmse);
+  etscalc_internal(&this->y[0], this->n, &this->state[0], this->m,
+                   this->errortype, this->trendtype, this->seasontype,
+                   this->alpha, this->beta, this->gamma, this->phi,
+                   &this->e[0], &this->fits[0], &this->lik, &this->amse[0], this->nmse);
 
 	// Avoid perfect fits
 	if (this->lik < -1e10) this->lik = -1e10;
@@ -280,9 +282,9 @@ bool EtsTargetFunction::admissible() {
 		std::vector<double> zeror(degree);
 		std::vector<double> zeroi(degree);
 
-		Rboolean fail;
+		bool fail;
 
-		cpolyroot(&opr[0], &opi[0], &degree, &zeror[0], &zeroi[0], &fail);
+		R_cpolyroot(&opr[0], &opi[0], &degree, &zeror[0], &zeroi[0], &fail);
 
 		double max = 0;
 		for(int i=0;i<zeror.size();i++) {
